searchNodes=[{"ref":"FaultTree.html","title":"FaultTree","type":"module","doc":"Main module for creating and interacting with fault trees."},{"ref":"FaultTree.html#add_and_gate/4","title":"FaultTree.add_and_gate/4","type":"function","doc":"Add an AND gate to the fault tree. All children must fail for this node to fail."},{"ref":"FaultTree.html#add_atleast_gate/6","title":"FaultTree.add_atleast_gate/6","type":"function","doc":"Add an ATLEAST/VOTING gate to the fault tree. This rqeuires that a minimum of K out of N child nodes fail in order to be marked as failing."},{"ref":"FaultTree.html#add_basic/3","title":"FaultTree.add_basic/3","type":"function","doc":"Add a basic node to the fault tree with a pre-defined probability."},{"ref":"FaultTree.html#add_basic/4","title":"FaultTree.add_basic/4","type":"function","doc":""},{"ref":"FaultTree.html#add_basic/5","title":"FaultTree.add_basic/5","type":"function","doc":""},{"ref":"FaultTree.html#add_logic/5","title":"FaultTree.add_logic/5","type":"function","doc":"Add a logic gate to the fault tree."},{"ref":"FaultTree.html#add_node/2","title":"FaultTree.add_node/2","type":"function","doc":"Add a node to the fault tree. Some validations are performed to make sure the node can logically be added to the tree."},{"ref":"FaultTree.html#add_or_gate/4","title":"FaultTree.add_or_gate/4","type":"function","doc":"Add an OR gate to the fault tree. Any child nodes failing will cause this node to fail."},{"ref":"FaultTree.html#add_transfer/3","title":"FaultTree.add_transfer/3","type":"function","doc":"Add a transfer node. This is a reference to a node that already exists in the tree. Transfer nodes cannot have anything modified, changes must happen on the source."},{"ref":"FaultTree.html#build/1","title":"FaultTree.build/1","type":"function","doc":""},{"ref":"FaultTree.html#create/0","title":"FaultTree.create/0","type":"function","doc":"Create a new fault tree with an OR gate as the root."},{"ref":"FaultTree.html#create/1","title":"FaultTree.create/1","type":"function","doc":"Create a new fault tree and generate a node of the given type for the root."},{"ref":"FaultTree.html#find_children/2","title":"FaultTree.find_children/2","type":"function","doc":""},{"ref":"FaultTree.html#parse/1","title":"FaultTree.parse/1","type":"function","doc":"Convert from a string containing fault tree logic into the tree object."},{"ref":"FaultTree.html#to_json/1","title":"FaultTree.to_json/1","type":"function","doc":"Convert a tree to JSON."},{"ref":"FaultTree.html#validate_atleast/2","title":"FaultTree.validate_atleast/2","type":"function","doc":"Validate that ATLEAST gates have their parameters set."},{"ref":"FaultTree.html#validate_name/2","title":"FaultTree.validate_name/2","type":"function","doc":"Validate that the name of the node is unique in the fault tree."},{"ref":"FaultTree.html#validate_node/2","title":"FaultTree.validate_node/2","type":"function","doc":"Perform some validation for a new node against the existing tree."},{"ref":"FaultTree.html#validate_parent/2","title":"FaultTree.validate_parent/2","type":"function","doc":"Validate that the gate types allow setting this node as a child of its listed parent."},{"ref":"FaultTree.html#validate_probability/2","title":"FaultTree.validate_probability/2","type":"function","doc":"Validate that a probability is only set on basic nodes. Logic gates will have their probability calculated when the tree is built."},{"ref":"FaultTree.html#validate_transfer/2","title":"FaultTree.validate_transfer/2","type":"function","doc":"Validate that TRANSFER gates have a source that exists in the tree."},{"ref":"FaultTree.html#t:error_type/0","title":"FaultTree.error_type/0","type":"type","doc":""},{"ref":"FaultTree.html#t:result/0","title":"FaultTree.result/0","type":"type","doc":""},{"ref":"FaultTree.html#t:t/0","title":"FaultTree.t/0","type":"type","doc":""},{"ref":"FaultTree.Analyzer.html","title":"FaultTree.Analyzer","type":"module","doc":"Handles building a fault tree out of an array of nodes."},{"ref":"FaultTree.Analyzer.html#probability/3","title":"FaultTree.Analyzer.probability/3","type":"function","doc":"Calculate the probability of failure for a given node. The node must have all of its children with defined probabilities. For TRANSFER gates, the probability is copied from the source node. If the source node was not calculated before the transfer gate is reached, the probability will be calculated twice. This will be inefficient, but mathemetically correct."},{"ref":"FaultTree.Analyzer.html#process/1","title":"FaultTree.Analyzer.process/1","type":"function","doc":"Converts a FaultTree struct into a hierarchical map."},{"ref":"FaultTree.Analyzer.Probability.html","title":"FaultTree.Analyzer.Probability","type":"module","doc":"Holds state when processing the probability across a fault tree. This is particularly useful for transfer gates when trying to determine the probability of their source node."},{"ref":"FaultTree.Analyzer.Probability.html#child_spec/1","title":"FaultTree.Analyzer.Probability.child_spec/1","type":"function","doc":"Returns a specification to start this module under a supervisor. See Supervisor."},{"ref":"FaultTree.Analyzer.Probability.html#lookup/2","title":"FaultTree.Analyzer.Probability.lookup/2","type":"function","doc":"Return the cached probability result for a given node."},{"ref":"FaultTree.Analyzer.Probability.html#save/2","title":"FaultTree.Analyzer.Probability.save/2","type":"function","doc":"Store the result of a probability calculation. Returns the node for chaining."},{"ref":"FaultTree.Gate.And.html","title":"FaultTree.Gate.And","type":"module","doc":"Handling for AND logic gates. P (A and B) = P (A ∩ B) = P(A) * P(B)"},{"ref":"FaultTree.Gate.And.html#probability/1","title":"FaultTree.Gate.And.probability/1","type":"function","doc":""},{"ref":"FaultTree.Gate.AtLeast.html","title":"FaultTree.Gate.AtLeast","type":"module","doc":"Handling for ATLEAST logic gates. P(A occurs K out of N times) = P(A:K of N) = (N/K) P(A)^K (1 - P(A))^(N-K) P(A atleast K of N) = sum(P(A:K of N), ..., P(A:N of N))"},{"ref":"FaultTree.Gate.AtLeast.html#calc/3","title":"FaultTree.Gate.AtLeast.calc/3","type":"function","doc":""},{"ref":"FaultTree.Gate.AtLeast.html#exact_calc/3","title":"FaultTree.Gate.AtLeast.exact_calc/3","type":"function","doc":"Calculate exactly K out of N occurances."},{"ref":"FaultTree.Gate.AtLeast.html#probability/2","title":"FaultTree.Gate.AtLeast.probability/2","type":"function","doc":""},{"ref":"FaultTree.Gate.Or.html","title":"FaultTree.Gate.Or","type":"module","doc":"Handling for OR logic gates. P (A or B) = P (A ∪ B) = P(A) + P(B) - P (A ∩ B)"},{"ref":"FaultTree.Gate.Or.html#probability/1","title":"FaultTree.Gate.Or.probability/1","type":"function","doc":""},{"ref":"FaultTree.Math.html","title":"FaultTree.Math","type":"module","doc":"Helper math functions."},{"ref":"FaultTree.Math.html#pow/2","title":"FaultTree.Math.pow/2","type":"function","doc":""},{"ref":"FaultTree.Node.html","title":"FaultTree.Node","type":"module","doc":"Individual nodes inside of a fault tree."},{"ref":"FaultTree.Node.html#t:node_type/0","title":"FaultTree.Node.node_type/0","type":"type","doc":"Logic gate type for a node."},{"ref":"FaultTree.Node.html#t:t/0","title":"FaultTree.Node.t/0","type":"type","doc":"A single node in the fault tree. id: unique ID for the node parent: ID of the parent node type: Gate type for the node name: Unique name for the node description: Verbose description of the node probability: Probability of failure. Calculated for all logic gate types, must be set for :basic atleast: Tuple of {k,n} for ATLEAST gate calculation. nil for everything else children: List of child nodes, used when the tree is built source: Name of the source node if this is a transfer."},{"ref":"FaultTree.Parser.XML.html","title":"FaultTree.Parser.XML","type":"module","doc":"Parse an XML document into a FaultTree. The XML schema expected is mostly for opsa-mef, defined at: https://github.com/rakhimov/scram/blob/master/share/input.rng"},{"ref":"FaultTree.Parser.XML.html#parse/1","title":"FaultTree.Parser.XML.parse/1","type":"function","doc":"Parse the XML document into a FaultTree. Steps: create a new tree parse xml and add all events/gates to the tree walk the tree and set parent field for anything showing up as a child of another node for duplicates, set all references after the first as a transfer gate walk the tree again and remove original child references Things missing: parameter parsing only the first defined fault-tree will be parsed unsupported gate types nested gates are not supported, each gate must be defined with define-gate and only use event refs boolean events a bunch of other things from https://raw.githubusercontent.com/rakhimov/scram/master/share/input.rng"},{"ref":"FaultTree.Router.html","title":"FaultTree.Router","type":"module","doc":"Handler for HTTP requests."},{"ref":"FaultTree.Router.html#__template_recompile__?/0","title":"FaultTree.Router.__template_recompile__?/0","type":"function","doc":"Returns true whenever the list of templates changes in the filesystem."},{"ref":"FaultTree.Router.html#__templates__/0","title":"FaultTree.Router.__templates__/0","type":"function","doc":"Returns the template root alongside all template filenames."},{"ref":"FaultTree.Router.html#call/2","title":"FaultTree.Router.call/2","type":"function","doc":"Callback implementation for Plug.call/2."},{"ref":"FaultTree.Router.html#do_match/3","title":"FaultTree.Router.do_match/3","type":"function","doc":"Pass-through route that matches all parameters. This ensures that the plug pipeline won&#39;t die if there are more plugs after this module."},{"ref":"FaultTree.Router.html#init/1","title":"FaultTree.Router.init/1","type":"function","doc":"Callback implementation for Plug.init/1."},{"ref":"FaultTree.Router.html#match/2","title":"FaultTree.Router.match/2","type":"function","doc":""},{"ref":"FaultTree.Router.html#render_template/2","title":"FaultTree.Router.render_template/2","type":"function","doc":""},{"ref":"readme.html","title":"FaultTree","type":"extras","doc":"FaultTree FaultTree is a library for performing fault tree analysis. It includes a small HTTP server capable of graphing the resulting FTA, or returning it as JSON."},{"ref":"readme.html#installation","title":"FaultTree - Installation","type":"extras","doc":"The FaultTree package can be installed from Hex by adding fault_tree to your list of dependencies in mix.exs: def deps do [ {:fault_tree, &quot;~&gt; 0.1.0&quot;} ] end Documentation can be found at https://hexdocs.pm/fault_tree."},{"ref":"readme.html#running","title":"FaultTree - Running","type":"extras","doc":"Run the server with mix trot.server, or iex -S mix for an interactive shell. The analysis can be run by uploading XML at http://localhost:4000/."},{"ref":"readme.html#input-format","title":"FaultTree - Input format","type":"extras","doc":"The expected input is an XML document matching the SCRAM/openpsa format. Alternatively, the fault tree can be created using Elixir code. Example: FaultTree.create(:or) |&gt; FaultTree.add_basic(&quot;root&quot;, &quot;0.01&quot;, &quot;foo&quot;) |&gt; FaultTree.add_basic(&quot;root&quot;, &quot;0.01&quot;, &quot;bar&quot;) |&gt; FaultTree.build() Will build the following tree: %FaultTree.Node{ atleast: nil, children: [ %FaultTree.Node{ atleast: nil, children: [], description: nil, id: 2, name: &quot;bar&quot;, parent: &quot;root&quot;, probability: #Decimal&lt;0.01&gt;, source: nil, type: :basic }, %FaultTree.Node{ atleast: nil, children: [], description: nil, id: 1, name: &quot;foo&quot;, parent: &quot;root&quot;, probability: #Decimal&lt;0.01&gt;, source: nil, type: :basic } ], description: nil, id: 0, name: &quot;root&quot;, parent: nil, probability: #Decimal&lt;0.0199&gt;, source: nil, type: :or }"}]